"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Routes = void 0;
const VERSION_KEY = Symbol('version');
class Routes {
    constructor(app) { }
    getAvailableVersions() {
        const prototype = Object.getPrototypeOf(this);
        const methodNames = Object.getOwnPropertyNames(prototype);
        return methodNames
            .map(name => Reflect.getMetadata(VERSION_KEY, prototype, name))
            .filter(Boolean); // supprime undefined
    }
    callVersion(version, router) {
        const prototype = Object.getPrototypeOf(this);
        const methodNames = Object.getOwnPropertyNames(prototype);
        for (const name of methodNames) {
            const metaVersion = Reflect.getMetadata(VERSION_KEY, prototype, name);
            if (metaVersion === version) {
                const method = this[name];
                if (typeof method === 'function') {
                    method.call(this, router);
                    return;
                }
            }
        }
        console.warn(`No route found for version "${version}"`);
    }
}
exports.Routes = Routes;
